@@ -1,7 +1,7 @@
 #! /bin/bash -e
 # SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 # SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-# SPDX-FileContributor: 2003-22 Bradley M. Bell
+# SPDX-FileContributor: 2003-24 Bradley M. Bell
 # ----------------------------------------------------------------------------
 if [  "$0" != 'bin/check_addon.sh' ]
 then
@@ -22,7 +22,7 @@ do
    then
       grep_cmd="CPPAD_${addon}_"
    else
-      grep_cmd="$grep_cmd|CPPAD_${addon}_"
+      grep_cmd+="|CPPAD_${addon}_"
    fi
 done
 #
