@@ -1,7 +1,7 @@
 #! /bin/bash -e
 # SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 # SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-# SPDX-FileContributor: 2003-22 Bradley M. Bell
+# SPDX-FileContributor: 2003-24 Bradley M. Bell
 # ----------------------------------------------------------------------------
 if [ ! -e "bin/check_include_xrst.sh" ]
 then
@@ -10,7 +10,7 @@ then
 fi
 # -----------------------------------------------------------------------------
 count=`git ls-files include/cppad | grep '/xrst/.*\.hpp' | wc -l`
-if [ "$count" != '0' ]
+if [ $count != '0' ]
 then
    git ls-files include/cppad | grep '/xrst/.*\.hpp'
    echo 'Cannot put *.hpp files below xrst in include directory'
