@@ -1,7 +1,7 @@
 #! /bin/bash -e
 # SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 # SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-# SPDX-FileContributor: 2003-23 Bradley M. Bell
+# SPDX-FileContributor: 2003-25 Bradley M. Bell
 # ----------------------------------------------------------------------------
 if [ "$0" != "bin/package.sh" ]
 then
@@ -12,16 +12,13 @@ echo_eval() {
      echo $*
      eval $*
 }
+# grep, sed
+source bin/grep_and_sed.sh
 # -----------------------------------------------------------------------------
-# index_page_name
-index_page_name=$(\
-   sed -n -e '/^ *--index_page_name*/p' .readthedocs.yaml | \
-   sed -e 's|^ *--index_page_name *||' \
-)
 #
 # version
-version=`sed -n -e '/^SET( *cppad_version *"[0-9.]*"/p' CMakeLists.txt | \
-   sed -e 's|.*"\([^"]*\)".*|\1|'`
+version=`$sed -n -e '/^SET( *cppad_version *"[0-9.]*"/p' CMakeLists.txt | \
+   $sed -e 's|.*"\([^"]*\)".*|\1|'`
 #
 # build
 if [ ! -e 'build' ]
@@ -40,9 +37,6 @@ cd build/cppad-$version
 tar -xzf tar.tgz
 rm tar.tgz
 #
-#  build/cppad-version/build/html
-bin/run_xrst.sh -dev
-#
 # build/cppad-$version.tgz
 cd ..
 echo_eval tar -czf cppad-$version.tgz cppad-$version
