@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 {xrst_begin code_gen_fun}
 {xrst_spell
-   cg
-   jrcv
+  cg
+  jrcv
 }
 
 Generate Source Code and Compile an AD Function
@@ -14,8 +14,7 @@ Generate Source Code and Compile an AD Function
 
 Syntax
 ******
-
-   # ``include <cppad/example/code_gen_fun.hpp>``
+| # ``include <cppad/example/code_gen_fun.hpp>``
 
 Constructors
 ============
@@ -193,12 +192,12 @@ a function (:ref:`sparse_jac_fun-name` ) or it's Jacobian to CppADCodeGen
 THis test indicates that both methods have similar setup
 and derivative calculation times.
 {xrst_toc_hidden
-   example/code_gen_fun/function.cpp
-   example/code_gen_fun/file.cpp
-   example/code_gen_fun/jacobian.cpp
-   example/code_gen_fun/jac_as_fun.cpp
-   example/code_gen_fun/sparse_jacobian.cpp
-   example/code_gen_fun/sparse_jac_as_fun.cpp
+   example/cppad_code_gen/function.cpp
+   example/cppad_code_gen/file.cpp
+   example/cppad_code_gen/jacobian.cpp
+   example/cppad_code_gen/jac_as_fun.cpp
+   example/cppad_code_gen/sparse_jacobian.cpp
+   example/cppad_code_gen/sparse_jac_as_fun.cpp
 }
 Examples
 ********
