@@ -2,24 +2,20 @@
 # define CPPAD_EXAMPLE_ABS_NORMAL_ABS_MIN_LINEAR_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 {xrst_begin abs_min_linear}
 {xrst_spell
-   affine
-   dbl
-   iterated
-   lll
-   maxitr
-   minimizer
+  dbl
+  lll
+  maxitr
 }
 abs_normal: Minimize a Linear Abs-normal Approximation
 ######################################################
 
 Syntax
 ******
-
 | *ok* = ``abs_min_linear`` (
 | |tab| *level* , *n* , *m* , *s* ,
 | |tab| *g_hat* , *g_jac* , *bound* , *epsilon* , *maxitr* , *delta_x*
