@@ -2,20 +2,20 @@
 # define CPPAD_EXAMPLE_ABS_NORMAL_ABS_PRINT_MAT_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 {xrst_begin abs_print_mat}
 {xrst_spell
-   cout
-   nr
+  cout
+  nr
 }
 abs_normal: Print a Vector or Matrix
 ####################################
 
 Syntax
 ******
-``abs_print_mat`` ( *name* , *nr* , *nc* , *mat* )
+| ``abs_print_mat`` ( *name* , *nr* , *nc* , *mat* )
 
 Prototype
 *********
