@@ -2,16 +2,17 @@
 # define CPPAD_EXAMPLE_ABS_NORMAL_QP_INTERIOR_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 {xrst_begin qp_interior}
 {xrst_spell
-   maxitr
-   rl
-   sout
-   xout
-   yout
+  maxitr
+  rl
+  sout
+  xin
+  xout
+  yout
 }
 
 Solve a Quadratic Program Using Interior Point Method
@@ -19,7 +20,6 @@ Solve a Quadratic Program Using Interior Point Method
 
 Syntax
 ******
-
 | *ok* = ``qp_interior`` (
 | *level* , *c* , *C* , *g* , *G* , *epsilon* , *maxitr* , *xin* , *xout* , *yout* , *sout*
 | )
@@ -177,7 +177,7 @@ The derivative of :math:`F_\mu` is given by
    \left( \begin{array}{ccc}
    G       & C^T  & 0_{n,m} \\
    C       & 0    & I_{m,m} \\
-   0_{m,m} & D(s) & D(y)
+   0_{m,m} & D(s) && D(y)
    \end{array} \right)
 
 The Newton step solves the following equation for
@@ -208,7 +208,7 @@ It follows that
    \left( \begin{array}{ccc}
    G       & C^T  & 0_{n,m} \\
    C       & 0    & I_{m,m} \\
-   0_{m,m} & D(s) & D(y)
+   0_{m,m} & D(s) && D(y)
    \end{array} \right)
    \left( \begin{array}{c} \Delta x \\ \Delta y \\ \Delta s \end{array} \right)
    =
