@@ -2,7 +2,7 @@
 # define CPPAD_LOCAL_OPTIMIZE_GET_PAR_USAGE_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-23 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*!
 \file get_cexp_info.hpp
@@ -15,9 +15,6 @@ namespace CppAD { namespace local { namespace optimize {
 
 /*!
 {xrst_begin optimize_get_par_usage dev}
-{xrst_spell
-   vecad
-}
 
 Use Reverse Activity Analysis to Get Usage for Each Parameter
 #############################################################
@@ -158,7 +155,7 @@ void get_par_usage(
    for(size_t i_op = 0; i_op < num_op; ++i_op)
    {
       // information about current operator
-      OpCode        op;     // operator
+      op_code_var   op;     // operator
       const addr_t* arg;    // arguments
       size_t        i_var;  // variable index of first result
       random_itr.op_info(i_op, op, arg, i_var);
@@ -438,7 +435,7 @@ void get_par_usage(
          type_x.resize(n);
          for(size_t j = 0; j < n; ++j)
          {  // parameter index zero is used for variable
-            CPPAD_ASSERT_UNKNOWN( isnan( all_par_vec[0] ) );
+            CPPAD_ASSERT_UNKNOWN( CppAD::isnan( all_par_vec[0] ) );
             addr_t arg_j = dyn_par_arg[i_arg + 5 + j];
             parameter_x[j] = all_par_vec[arg_j];
             if( arg_j == 0 )
@@ -467,7 +464,7 @@ void get_par_usage(
          // transfer depend_x to par_usage
          for(size_t j = 0; j < n; ++j)
          {  size_t i_par = size_t( dyn_par_arg[i_arg + 5 + j] );
-            par_usage[i_par] = par_usage[i_par] | depend_x[j];
+            par_usage[i_par] = par_usage[i_par] || depend_x[j];
          }
       }
       else
