@@ -2,7 +2,7 @@
 # define CPPAD_LOCAL_SPARSE_SIZE_SETVEC_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-23 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 # include <cppad/local/pod_vector.hpp>
 /*
@@ -38,7 +38,7 @@ class size_setvec { // BEGIN_CLASS_LIST_SETVEC
 -------------------------------------------------------------------------------
 {xrst_begin size_setvec_member_data dev}
 {xrst_spell
-   struct
+  struct
 }
 
 class size_setvec: Private Member Data
@@ -167,7 +167,7 @@ class size_setvec private: Number of References to a Set
 
 Syntax
 ******
-*count* = *vec* . ``reference_count`` ( *i* )
+| *count* = *vec* . ``reference_count`` ( *i* )
 
 vec
 ***
@@ -203,9 +203,6 @@ private:
 /*
 ------------------------------------------------------------------------------
 {xrst_begin size_setvec_drop dev}
-{xrst_spell
-   decremented
-}
 class size_setvec private: Drop a Set No Longer Being Used
 ##########################################################
 
@@ -318,9 +315,6 @@ private:
 /*
 ------------------------------------------------------------------------------
 {xrst_begin size_setvec_get_data_index dev}
-{xrst_spell
-   decremented
-}
 
 class size_setvec private: Get a New List Pair
 ##############################################
@@ -549,7 +543,7 @@ public:
 -------------------------------------------------------------------------------
 {xrst_begin size_setvec_iterators dev}
 {xrst_spell
-   typedef
+  typedef
 }
 
 class size_setvec: Iterators
@@ -1249,7 +1243,7 @@ public:
       CPPAD_ASSERT_UNKNOWN( end_        == other.end_   );
 
       // check if we are assigning a set to itself
-      if( (this == &other) & (this_target == other_source) )
+      if( (this == &other) && (this_target == other_source) )
          return;
 
       // set depending on cases below
@@ -1368,7 +1362,7 @@ public:
       bool left_is_subset  = true;
       bool right_is_subset = true;
 
-      while( (value_left < end_) & (value_right < end_) )
+      while( (value_left < end_) && (value_right < end_) )
       {  if( value_left == value_right )
          {  // value is in both sets
             temporary_.push_back(value_left);
@@ -1484,7 +1478,7 @@ public:
       s_type start_right   = other.start_[other_right];
 
       // if left or right is empty, the result is empty
-      if( (start_left == 0) | (start_right == 0) )
+      if( (start_left == 0) || (start_right == 0) )
       {  clear(this_target);
          return;
       }
@@ -1510,7 +1504,7 @@ public:
       bool left_is_subset  = true;
       bool right_is_subset = true;
 
-      while( (value_left < end_) & (value_right < end_) )
+      while( (value_left < end_) && (value_right < end_) )
       {  if( value_left == value_right )
          {  // value is in both sets
             temporary_.push_back(value_left);
