@@ -2,15 +2,18 @@
 # define CPPAD_LOCAL_SWEEP_FOR_HES_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-23 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 
 # include <cppad/local/play/atom_op_info.hpp>
+# include <cppad/local/var_op/load_op.hpp>
+# include <cppad/local/var_op/store_op.hpp>
+# include <cppad/local/var_op/csum_op.hpp>
 
 /*
 {xrst_begin local_sweep_for_hes dev}
 {xrst_spell
-   numvar
+  inv
 }
 
 Forward Mode Hessian Sparsity Patterns
@@ -18,11 +21,10 @@ Forward Mode Hessian Sparsity Patterns
 
 Syntax
 ******
-
 | ``local::sweep::for_hes`` (
 | |tab| *play*               ,
 | |tab| *n*                  ,
-| |tab| *numvar*             ,
+| |tab| *num_var*            ,
 | |tab| *select_domain*      ,
 | |tab| *rev_jac_sparse*     ,
 | |tab| *for_hes_sparse*     ,
@@ -43,8 +45,8 @@ and the reverse Jacobian sparsity pattern for the dependent variables,
 ``for_hes`` computes the Hessian sparsity pattern for all the independent
 variables.
 
-Tracing
-*******
+CPPAD_FOR_HES_TRACE
+*******************
 This value is either zero or one.  Zero is the normal operational value.
 If it is one, a trace of Jacobian and Hessian sparsity result for every
 operation for every ``for_hes`` sweep is printed.
@@ -54,11 +56,6 @@ the corresponding index is (is not) in the set.
 # define CPPAD_FOR_HES_TRACE 0
 /* {xrst_code}
 
-Addr
-****
-Is the type used to record address on this tape
-This is allows for smaller tapes when address are smaller.
-
 Base
 ****
 The operation sequence in *play* was recorded using
@@ -85,8 +82,8 @@ n
 *
 is the number of independent variables in the tape.
 
-numvar
-******
+num_var
+*******
 is the total number of variables in the tape; i.e.,
 *play* ``->num_var_rec`` () .
 This is also the number of sets in all the sparsity patterns.
@@ -102,36 +99,44 @@ as the order of the InvOp operators.
 
 rev_jac_sparse
 **************
-Is a sparsity pattern with size *numvar* by one.
-For *i* =1, ..., *numvar* ``-1`` ,
-the if the function we are computing the Hessian for has a non-zero
-derivative w.r.t. variable with index *i* ,
+Is a sparsity pattern with size *num_var* by one.
+For *i* =1, ..., *num_var* ``-1`` ,
+the if the scalar valued function we are computing the Hessian sparsity for
+has a non-zero derivative w.r.t. variable with index *i* ,
 the set with index *i* has the element zero.
 Otherwise it has no elements.
 
 for_hes_sparse
 **************
-Is a sparsity pattern with size *n* +1+ *numvar* by *n* +1 .
-The set with index zero and the element zero are not used.
-The sets with index greater than *n*
-are used for forward Jacobian sparsity.
-The forward Hessian sparsity pattern for the variable with index *i*
-corresponds to the set with index *i* in *for_hes_sparse* .
-The number of sets in this sparsity pattern is *n* +1 and the set
-with index zero is not used.
+This is a sparsity pattern with *n* + 1 + *num_var* sets
+and end value *n* + 1 .
+On input, all of the sets are empty.
+On output, it contains the two sparsity patterns described below:
 
-On Input
-========
-For *j* =1, ..., *n* ,
-the forward Hessian sparsity pattern for the variable with index
-*i* is empty.
+Hessian Sparsity
+================
+For *j* equal 1 to *n* ,
+if *i* is in set with index *j* ,
+the Hessian may have a non-zero partial with respect to the
+independent variables with indices ( *i* - 1, *j* - 1 ) .
+Note that the index zero is not used because it corresponds to the
+phantom variable on the tape.
 
-On Output
-=========
-For *j* =1, ..., *n* ,
-the forward Hessian sparsity pattern for the independent dependent variable
-with index *j* ``-1`` is given by the set with index *j*
-in *for_hes_sparse* .
+Jacobian Sparsity
+=================
+For *k* equal 1 to *num_var* - 1 ,
+if *i* is in the set with index *n* + 1 + *k* ,
+the variable with index *k* may have a non-zero partial with resect to the
+independent variable with index *i* - 1 .
+
+Method
+======
+For *k* equal 1 to *num_var* - 1,
+the Jacobian sparsity pattern for variable with index *k* is computed using
+the previous Jacobian sparsity patterns.
+The Hessian sparsity pattern is updated using linear and non-linear
+interactions for the variable with index *k* and the previous Jacobian
+sparsity patterns.
 
 not_used_rec_base
 *****************
@@ -144,11 +149,11 @@ This argument is only used to specify the type *RecBase* for this call.
 namespace CppAD { namespace local { namespace sweep {
 
 // BEGIN PROTOTYPE
-template <class Addr, class Base, class SetVector, class RecBase>
+template <class Base, class SetVector, class RecBase>
 void for_hes(
    const local::player<Base>* play                ,
    size_t                     n                   ,
-   size_t                     numvar              ,
+   size_t                     num_var             ,
    const pod_vector<bool>&    select_domain       ,
    const SetVector&           rev_jac_sparse      ,
    SetVector&                 for_hes_sparse      ,
@@ -163,28 +168,26 @@ void for_hes(
    // check arguments
    size_t np1 = n+1;
    CPPAD_ASSERT_UNKNOWN( select_domain.size()   == n );
-   CPPAD_ASSERT_UNKNOWN( play->num_var_rec()    == numvar );
-   CPPAD_ASSERT_UNKNOWN( rev_jac_sparse.n_set() == numvar );
-   CPPAD_ASSERT_UNKNOWN( for_hes_sparse.n_set() == np1+numvar );
+   CPPAD_ASSERT_UNKNOWN( play->num_var_rec()    == num_var );
+   CPPAD_ASSERT_UNKNOWN( rev_jac_sparse.n_set() == num_var );
+   CPPAD_ASSERT_UNKNOWN( for_hes_sparse.n_set() == np1+num_var );
    //
    CPPAD_ASSERT_UNKNOWN( rev_jac_sparse.end()   == 1   );
    CPPAD_ASSERT_UNKNOWN( for_hes_sparse.end()   == np1 );
    //
-   CPPAD_ASSERT_UNKNOWN( numvar > 0 );
+   CPPAD_ASSERT_UNKNOWN( num_var > 0 );
    //
-   // vecad_sparsity contains a sparsity pattern for each VecAD object.
-   // vecad_ind maps a VecAD index (beginning of the VecAD object)
-   // to the index for the corresponding set in vecad_sparsity.
+   // vecad_sparsity: forward Jacobian sparsity pattern for each VecAD object.
+   // vecad_ind: maps the VecAD index at beginning of the VecAD object
+   //            to the index for the corresponding set in vecad_sparsity.
    size_t num_vecad_ind   = play->num_var_vecad_ind_rec();
    size_t num_vecad_vec   = play->num_var_vecad_rec();
-   SetVector vecad_sparse;
+   SetVector vecad_sparsity;
    pod_vector<size_t> vecad_ind;
-   pod_vector<bool>   vecad_jac;
    if( num_vecad_vec > 0 )
    {  size_t length;
-      vecad_sparse.resize(num_vecad_vec, np1);
+      vecad_sparsity.resize(num_vecad_vec, np1);
       vecad_ind.extend(num_vecad_ind);
-      vecad_jac.extend(num_vecad_vec);
       size_t j  = 0;
       for(size_t i = 0; i < num_vecad_vec; i++)
       {  // length of this VecAD
@@ -196,51 +199,38 @@ void for_hes(
             vecad_ind[j+k] = num_vecad_vec;
          // start of next VecAD
          j       += length + 1;
-         // initialize this vector's reverse jacobian value
-         vecad_jac[i] = false;
       }
       CPPAD_ASSERT_UNKNOWN( j == play->num_var_vecad_ind_rec() );
    }
    // ------------------------------------------------------------------------
-   // work space used by AFunOp.
-   vector<Base>         atom_x;  //// value of parameter arguments to function
-   vector<ad_type_enum> type_x;  // argument types
-   pod_vector<size_t>   atom_ix; // variable index (on tape) for each argument
-   pod_vector<size_t>   atom_iy; // variable index (on tape) for each result
+   // work space used by atomic funcions
+   var_op::atomic_op_work<Base> atom_work;
    //
-   // information set by atomic forward (initialization to avoid warnings)
-   size_t atom_index=0, atom_old=0, atom_m=0, atom_n=0, atom_i=0, atom_j=0;
-   // information set by atomic forward (necessary initialization)
-   enum_atom_state atom_state = start_atom;
-   // -------------------------------------------------------------------------
    //
    // pointer to the beginning of the parameter vector
    // (used by atomic functions)
    CPPAD_ASSERT_UNKNOWN( num_par > 0 )
    const Base* parameter = play->GetPar();
    //
-   // which parametes are dynamic
-   const pod_vector<bool>& dyn_par_is( play->dyn_par_is() );
-   //
    // skip the BeginOp at the beginning of the recording
    play::const_sequential_iterator itr = play->begin();
    // op_info
-   OpCode op;
-   size_t i_var;
-   const Addr*   arg;
+   op_code_var   op;
+   size_t        i_var;
+   const addr_t* arg;
    itr.op_info(op, arg, i_var);
    CPPAD_ASSERT_UNKNOWN( op == BeginOp );
 # if CPPAD_FOR_HES_TRACE
-   vector<Addr> atom_funrp; // parameter index for FunrpOp operators
    std::cout << std::endl;
-   CppAD::vectorBool zf_value(np1);
-   CppAD::vectorBool zh_value(np1 * np1);
+   bool atom_trace = true;
+# else
+   bool atom_trace = false;
 # endif
-   bool   flag; // temporary for use in switch cases below
    bool   more_operators = true;
    size_t count_independent = 0;
    while(more_operators)
-   {
+   {  bool linear[3];
+
       // next op
       (++itr).op_info(op, arg, i_var);
 
@@ -249,22 +239,42 @@ void for_hes(
       bool include = NumRes(op) > 0;
       if( include )
          include = rev_jac_sparse.is_element(i_var, 0);
-      //
-      // operators to include even if derivative is zero
-      include |= op == EndOp;
-      include |= op == CSkipOp;
-      include |= op == CSumOp;
-      include |= op == AFunOp;
-      include |= op == FunapOp;
-      include |= op == FunavOp;
-      include |= op == FunrpOp;
-      include |= op == FunrvOp;
-      //
-      if( ! include )
-      {  if( op == InvOp )
+      switch( op )
+      {
+         // include
+         // operators that must always be included
+         case EndOp:
+         case CSkipOp:
+         case AFunOp:
+         case FunapOp:
+         case FunavOp:
+         case FunrpOp:
+         case FunrvOp:
+         case StppOp:
+         case StpvOp:
+         case StvpOp:
+         case StvvOp:
+         include = true;
+         break;
+
+         // count_independent
+         case InvOp:
+         if( ! include )
             ++count_independent;
+         break;
+
+         // itr
+         case CSumOp:
+         if( ! include )
+            itr.correct_before_increment();
+         break;
+
+         // default
+         default:
+         break;
       }
-      else switch( op )
+      //
+      if( include ) switch( op )
       {  // operators that should not occurr
          // case BeginOp
 
@@ -272,15 +282,9 @@ void for_hes(
          // and where with a fixed number of arguments and results
          case CExpOp:
          case DisOp:
-         case LdpOp:
-         case LdvOp:
          case ParOp:
          case PriOp:
          case SignOp:
-         case StppOp:
-         case StpvOp:
-         case StvpOp:
-         case StvvOp:
          break;
          // -------------------------------------------------
 
@@ -297,41 +301,62 @@ void for_hes(
 
          // -------------------------------------------------
          // linear operators where arg[0] is the only variable
-         // only assign Jacobian term J(i_var)
          case AbsOp:
          case DivvpOp:
          case SubvpOp:
          case ZmulvpOp:
-         for_hes_sparse.assignment(
-            np1 + i_var, np1 + size_t(arg[0]), for_hes_sparse
+         linear[0] = true;
+         var_op::one_var_for_hes(
+            np1, num_var, i_var, size_t(arg[0]), linear, for_hes_sparse
          );
          break;
 
          // -------------------------------------------------
          // linear operators where arg[1] is the only variable
-         // only assign Jacobian term J(i_var)
          case AddpvOp:
          case MulpvOp:
          case SubpvOp:
-         for_hes_sparse.assignment(
-            np1 + i_var, np1 + size_t(arg[1]), for_hes_sparse
+         linear[0] = true;
+         var_op::one_var_for_hes(
+            np1, num_var, i_var, size_t(arg[1]), linear, for_hes_sparse
          );
          break;
 
          // -------------------------------------------------
          // linear operators where arg[0] and arg[1] are variables
-         // only assign Jacobian term J(i_var)
          case AddvvOp:
          case SubvvOp:
-         for_hes_sparse.binary_union(
-            np1 + i_var          ,
-            np1 + size_t(arg[0]) ,
-            np1 + size_t(arg[1]) ,
-            for_hes_sparse
+         linear[0] = true;
+         linear[1] = true;
+         linear[2] = true;
+         var_op::two_var_for_hes(
+            np1, num_var, i_var, arg, linear, for_hes_sparse
          );
          break;
 
-         // nonlinear unary operators
+         // ------------------------------------------------------
+         // VecAD load operators
+         case LdvOp:
+         case LdpOp:
+         var_op::load_for_hes(
+            op, arg, num_vecad_ind, i_var, n,
+            vecad_ind, vecad_sparsity, for_hes_sparse
+         );
+         break;
+         //
+         // VecAD store operators
+         case StppOp:
+         case StpvOp:
+         case StvpOp:
+         case StvvOp:
+         var_op::store_for_hes(op,
+            arg, num_vecad_ind, n,
+            vecad_ind, vecad_sparsity, for_hes_sparse
+         );
+         break;
+
+         // ------------------------------------------------------
+         // nonlinear operators where arg[0] is the only variable
          case AcosOp:
          case AsinOp:
          case AtanOp:
@@ -350,9 +375,12 @@ void for_hes(
          case AtanhOp:
          case Expm1Op:
          case Log1pOp:
-         CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 )
-         sparse::for_hes_nl_unary_op(
-            np1, numvar, i_var, size_t(arg[0]), for_hes_sparse
+         case ErfOp:
+         case ErfcOp:
+         CPPAD_ASSERT_UNKNOWN( 0 < NumArg(op) )
+         linear[0] = false;
+         var_op::one_var_for_hes(
+               np1, num_var, i_var, size_t(arg[0]), linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
@@ -363,22 +391,27 @@ void for_hes(
          // -------------------------------------------------
 
          case CSumOp:
+         var_op::csum_for_hes(arg, i_var, n, for_hes_sparse);
          itr.correct_before_increment();
          break;
          // -------------------------------------------------
 
          case DivvvOp:
+         linear[0] = true;
+         linear[1] = false;
+         linear[2] = false;
          CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-         sparse::for_hes_div_op(
-            np1, numvar, i_var, arg, for_hes_sparse
+         var_op::two_var_for_hes(
+            np1, num_var, i_var, arg, linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
-
+         // nonlinear operators where arg[1] is the only variable
          case DivpvOp:
          CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-         sparse::for_hes_nl_unary_op(
-            np1, numvar, i_var, size_t(arg[1]), for_hes_sparse
+         linear[0] = false;
+         var_op::one_var_for_hes(
+               np1, num_var, i_var, size_t(arg[1]), linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
@@ -387,18 +420,6 @@ void for_hes(
          CPPAD_ASSERT_NARG_NRES(op, 0, 0);
          more_operators = false;
          break;
-         // -------------------------------------------------
-
-         case ErfOp:
-         case ErfcOp:
-         // arg[1] is always the parameter 0
-         // arg[2] is always the parameter 2 / sqrt(pi)
-         CPPAD_ASSERT_NARG_NRES(op, 3, 5);
-         sparse::for_hes_nl_unary_op(
-            np1, numvar, i_var, size_t(arg[0]), for_hes_sparse
-         );
-         break;
-         // -------------------------------------------------
 
          // -------------------------------------------------
          // logical comparison operators
@@ -421,235 +442,74 @@ void for_hes(
          // -------------------------------------------------
 
          case MulvvOp:
+         case ZmulvvOp:
+         linear[0] = true;
+         linear[1] = true;
+         linear[2] = false;
          CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-         sparse::for_hes_mul_op(
-            np1, numvar, i_var, arg, for_hes_sparse
+         var_op::two_var_for_hes(
+            np1, num_var, i_var, arg, linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
 
          case PowpvOp:
          CPPAD_ASSERT_NARG_NRES(op, 2, 3)
-         sparse::for_hes_nl_unary_op(
-            np1, numvar, i_var, size_t(arg[1]), for_hes_sparse
+         linear[0] = false;
+         var_op::one_var_for_hes(
+               np1, num_var, i_var, size_t(arg[1]), linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
 
          case PowvpOp:
          CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-         sparse::for_hes_nl_unary_op(
-            np1, numvar, i_var, size_t(arg[0]), for_hes_sparse
+         linear[0] = false;
+         var_op::one_var_for_hes(
+               np1, num_var, i_var, size_t(arg[0]), linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
 
          case PowvvOp:
+         linear[0] = false;
+         linear[1] = false;
+         linear[2] = false;
          CPPAD_ASSERT_NARG_NRES(op, 2, 3)
-         sparse::for_hes_pow_op(
-            np1, numvar, i_var, arg, for_hes_sparse
+         var_op::two_var_for_hes(
+            np1, num_var, i_var, arg, linear, for_hes_sparse
          );
          break;
          // -------------------------------------------------
 
          case AFunOp:
-         // start or end an atomic function call
-         CPPAD_ASSERT_UNKNOWN(
-            atom_state == start_atom || atom_state == end_atom
+         var_op::atomic_for_hes<SetVector, Base, RecBase>(
+            itr,
+            play,
+            parameter,
+            atom_trace,
+            atom_work,
+            np1,
+            rev_jac_sparse,
+            for_hes_sparse
          );
-         flag = atom_state == start_atom;
-         play::atom_op_info<RecBase>(
-            op, arg, atom_index, atom_old, atom_m, atom_n
-         );
-         if( flag )
-         {  atom_state = arg_atom;
-            atom_i     = 0;
-            atom_j     = 0;
-            //
-            atom_x.resize( atom_n );
-            type_x.resize( atom_n );
-            atom_ix.resize( atom_n );
-            atom_iy.resize( atom_m );
-# if CPPAD_FOR_HES_TRACE
-            atom_funrp.resize( atom_m );
-# endif
-         }
-         else
-         {  CPPAD_ASSERT_UNKNOWN( atom_i == atom_m );
-            CPPAD_ASSERT_UNKNOWN( atom_j == atom_n );
-            atom_state = start_atom;
-            //
-            call_atomic_for_hes_sparsity<Base,RecBase>(
-               atom_index, atom_old, atom_x, type_x, atom_ix, atom_iy,
-               np1, numvar, rev_jac_sparse, for_hes_sparse
-            );
-         }
          break;
 
          case FunapOp:
-         // parameter argument for an atomic function
-         CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
-         CPPAD_ASSERT_UNKNOWN( atom_state == arg_atom );
-         CPPAD_ASSERT_UNKNOWN( atom_i == 0 );
-         CPPAD_ASSERT_UNKNOWN( atom_j < atom_n );
-         CPPAD_ASSERT_UNKNOWN( size_t( arg[0] ) < num_par );
-         //
-         atom_x[atom_j] = parameter[arg[0]];
-         // argument type
-         if( dyn_par_is[arg[0]] )
-            type_x[atom_j] = dynamic_enum;
-         else
-            type_x[atom_j] = constant_enum;
-         atom_ix[atom_j] = 0; // special variable used for parameters
-         //
-         ++atom_j;
-         if( atom_j == atom_n )
-            atom_state = ret_atom;
-         break;
-
          case FunavOp:
-         // variable argument for an atomic function
-         CPPAD_ASSERT_UNKNOWN( NumArg(op) == 1 );
-         CPPAD_ASSERT_UNKNOWN( atom_state == arg_atom );
-         CPPAD_ASSERT_UNKNOWN( atom_i == 0 );
-         CPPAD_ASSERT_UNKNOWN( atom_j < atom_n );
-         CPPAD_ASSERT_UNKNOWN( 0 < arg[0] );
-         CPPAD_ASSERT_UNKNOWN( size_t( arg[0] ) < numvar );
-         //
-         // arguemnt variables not avaialbe during sparisty calculations
-         atom_x[atom_j] = CppAD::numeric_limits<Base>::quiet_NaN();
-         type_x[atom_j] = variable_enum;
-         atom_ix[atom_j] = size_t(arg[0]); // variable for this argument
-         //
-         ++atom_j;
-         if( atom_j == atom_n )
-            atom_state = ret_atom;
-         break;
-
          case FunrpOp:
-         // parameter result for an atomic function
-         CPPAD_ASSERT_NARG_NRES(op, 1, 0);
-         CPPAD_ASSERT_UNKNOWN( atom_state == ret_atom );
-         CPPAD_ASSERT_UNKNOWN( atom_i < atom_m );
-         CPPAD_ASSERT_UNKNOWN( atom_j == atom_n );
-         CPPAD_ASSERT_UNKNOWN( size_t( arg[0] ) < num_par );
-         //
-         atom_iy[atom_i] = 0; // special variable used for parameters
-# if CPPAD_FOR_HES_TRACE
-         // remember argument for delayed tracing
-         atom_funrp[atom_i] = arg[0];
-# endif
-         ++atom_i;
-         if( atom_i == atom_m )
-            atom_state = end_atom;
-         break;
-
          case FunrvOp:
-         // variable result for an atomic function
-         CPPAD_ASSERT_NARG_NRES(op, 0, 1);
-         CPPAD_ASSERT_UNKNOWN( atom_state == ret_atom );
-         CPPAD_ASSERT_UNKNOWN( atom_i < atom_m );
-         CPPAD_ASSERT_UNKNOWN( atom_j == atom_n );
-         //
-         atom_iy[atom_i] = i_var; // variable index for this result
-         //
-         ++atom_i;
-         if( atom_i == atom_m )
-            atom_state = end_atom;
+         CPPAD_ASSERT_UNKNOWN( false );
          break;
          // -------------------------------------------------
 
-         case ZmulvvOp:
-         CPPAD_ASSERT_NARG_NRES(op, 2, 1)
-         sparse::for_hes_mul_op(
-            np1, numvar, i_var, arg, for_hes_sparse
-         );
-         break;
-
-         // -------------------------------------------------
-
          default:
          CPPAD_ASSERT_UNKNOWN(0);
       }
 # if CPPAD_FOR_HES_TRACE
-      typedef typename SetVector::const_iterator const_iterator;
-      if( op == AFunOp && atom_state == start_atom )
-      {  // print operators that have been delayed
-         CPPAD_ASSERT_UNKNOWN( atom_m == atom_iy.size() );
-         CPPAD_ASSERT_UNKNOWN( itr.op_index() > atom_m );
-         CPPAD_ASSERT_NARG_NRES(FunrpOp, 1, 0);
-         CPPAD_ASSERT_NARG_NRES(FunrvOp, 0, 1);
-         addr_t arg_tmp[1];
-         for(size_t k = 0; k < atom_m; k++)
-         {  size_t k_var = atom_iy[k];
-            // value for this variable
-            for(size_t i = 0; i < np1; i++)
-            {  zf_value[i] = false;
-               for(size_t j = 0; j < np1; j++)
-                  zh_value[i * np1 + j] = false;
-            }
-            const_iterator itr_1(for_hes_sparse, np1 + i_var);
-            size_t j = *itr_1;
-            while( j < np1 )
-            {  zf_value[j] = true;
-               j = *(++itr_1);
-            }
-            for(size_t i = 0; i < np1; i++)
-            {  const_iterator itr_2(for_hes_sparse, i);
-               j = *itr_2;
-               while( j < np1 )
-               {  zh_value[i * np1 + j] = true;
-                  j = *(++itr_2);
-               }
-            }
-            OpCode op_tmp = FunrvOp;
-            if( k_var == 0 )
-            {  op_tmp     = FunrpOp;
-               arg_tmp[0] = atom_funrp[k];
-            }
-            // k_var is zero when there is no result
-            printOp<Base, RecBase>(
-               std::cout,
-               play,
-               itr.op_index() - atom_m + k,
-               k_var,
-               op_tmp,
-               arg_tmp
-            );
-            if( k_var > 0 ) printOpResult(
-               std::cout,
-               1,
-               &zf_value,
-               1,
-               &zh_value
-            );
-            std::cout << std::endl;
-         }
-      }
-      for(size_t i = 0; i < np1; i++)
-      {  zf_value[i] = false;
-         for(size_t j = 0; j < np1; j++)
-            zh_value[i * np1 + j] = false;
-      }
-      const_iterator itr_1(for_hes_sparse, np1 + i_var);
-      size_t j = *itr_1;
-      while( j < np1 )
-      {  zf_value[j] = true;
-         j = *(++itr_1);
-      }
-      for(size_t i = 0; i < np1; i++)
-      {  const_iterator itr_2(for_hes_sparse, i);
-         j = *itr_2;
-         while( j < np1 )
-         {  zh_value[i * np1 + j] = true;
-            j = *(++itr_2);
-         }
-      }
-      // must delay print for these cases till after atomic function call
-      bool delay_print = op == FunrpOp;
-      delay_print     |= op == FunrvOp;
-      if( ! delay_print )
-      {    printOp<Base, RecBase>(
+      if( op != AFunOp )
+      {  //
+         printOp<Base, RecBase>(
             std::cout,
             play,
             itr.op_index(),
@@ -657,14 +517,50 @@ void for_hes(
             op,
             arg
          );
-         if( NumRes(op) > 0 && (! delay_print) ) printOpResult(
-            std::cout,
-            1,
-            &zf_value,
-            1,
-            &zh_value
-         );
-         std::cout << std::endl;
+         //
+         if( NumRes(op) > 0 )
+         {  typedef typename SetVector::const_iterator itr_sparse_t;
+            CPPAD_ASSERT_UNKNOWN( np1 == for_hes_sparse.end() );
+            CppAD::vectorBool jac_row(np1);
+            for(size_t j = 0; j < np1; ++j)
+               jac_row[j] = false;
+            itr_sparse_t itr_jac(for_hes_sparse, np1 + i_var);
+            {  size_t j = *itr_jac;
+               while( j < np1 )
+               {  jac_row[j] = true;
+                  j = *(++itr_jac);
+               }
+            }
+            printOpResult(
+               std::cout,
+               1,
+               &jac_row,
+               0,
+               (CppAD::vectorBool *) nullptr
+            );
+            std::cout << std::endl;
+            //
+            CppAD::vector< CppAD::vectorBool > hes(np1);
+            for(size_t i = 0; i < np1; ++i)
+            {  hes[i].resize(np1);
+               for(size_t j = 0; j < np1; ++j)
+                  hes[i][j] = false;
+               itr_sparse_t itr_hes(for_hes_sparse, i);
+               size_t j = *itr_hes;
+               while( j < np1 )
+               {  hes[i][j] = true;
+                  j = *(++itr_hes);
+               }
+            }
+            printOpResult(
+               std::cout,
+               np1,
+               hes.data(),
+               0,
+               (CppAD::vectorBool *) nullptr
+            );
+            std::cout << std::endl;
+         }
       }
    }
    std::cout << std::endl;
