@@ -2,13 +2,13 @@
 # define CPPAD_UTILITY_SPARSE2EIGEN_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 
 /*
 {xrst_begin sparse2eigen}
 {xrst_spell
-   nnz
+  nnz
 }
 
 Convert A CppAD Sparse Matrix to an Eigen Sparse Matrix
@@ -16,10 +16,8 @@ Convert A CppAD Sparse Matrix to an Eigen Sparse Matrix
 
 Syntax
 ******
-
-   # ``include <cppad/utility/sparse2eigen.hpp>``
-
-``sparse2eigen`` ( *source* , *destination* )
+| # ``include <cppad/utility/sparse2eigen.hpp>``
+| ``sparse2eigen`` ( *source* , *destination* )
 
 Prototype
 *********
@@ -30,7 +28,7 @@ Prototype
 
 Include
 *******
-If :ref:`cmake@include_eigen` is specified on the cmake command line,
+If :ref:`cmake@Eigen` is found (and c++14 is supported),
 the file ``cppad/utility/sparse2eigen.hpp``
 is included by ``cppad/cppad.hpp`` .
 In any case,
