@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-23 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 // 2DO: Test that optimize.hpp use of atomic_base<Base>::rev_sparse_jac works.
 
@@ -1789,8 +1789,8 @@ namespace {
       ty[1] = tx[1] + tx[2];
 
       if( vy.size() > 0 )
-      {  vy[0] = vx[0] | vx[1];
-         vy[1] = vx[1] | vx[2];
+      {  vy[0] = vx[0] || vx[1];
+         vy[1] = vx[1] || vx[2];
       }
       return true;
    }
@@ -1999,7 +1999,7 @@ namespace {
       CppAD::ADFun<double> f(ax, ay);
 
       // run case that skips the second call to afun
-      // (can use trace in forward0sweep.hpp to see this).
+      // (can use trace in sweep/forward_0.hpp to see this).
       vector<double> x(2), y_before(1), y_after(1);
       x[0]      = 1.0;
       x[1]      = 2.0;
