@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 
 /*
@@ -395,7 +395,6 @@ bool Sinh(void)
 } // End empty namespace
 
 bool SinCos(void)
-{  bool ok = Sin() & Cos() & Cosh() & Sinh();
+{  bool ok = Sin() && Cos() && Cosh() && Sinh();
    return ok;
 }
-
